@@ -54,9 +54,11 @@ class Aggs(list):
             # polygon doesn't return in ascending order
             # Do not rely on df.sort_values() as this library
             # may be used with older pandas
+            keycol = 't' if size[0] == 'm' else 'd'
+            columns = ('o', 'h', 'l', 'c', 'v', keycol)
             df = pd.DataFrame(
-                sorted(raw['ticks'], key=lambda d: d['d']),
-                columns=('o', 'h', 'l', 'c', 'v', 'd'),
+                sorted(raw['ticks'], key=lambda d: d[keycol]),
+                columns=columns,
             )
             df.columns = [raw['map'][c] for c in df.columns]
             if size[0] == 'm':
@@ -77,6 +79,42 @@ class Aggs(list):
         return self._df
 
 
+class Aggsv2(list):
+    def __init__(self, raw):
+        results = raw['results'] if raw.get('results') else []
+        super().__init__(
+            [Agg(tick) for tick in results]
+        )
+        self._raw = raw
+
+    @property
+    def df(self):
+        if not hasattr(self, '_df'):
+            results = self._raw['results']
+            columns = ('o', 'h', 'l', 'c', 'v', 't')
+            df = pd.DataFrame(
+                results, columns=columns
+            )
+            df.set_index('t', inplace=True)
+            self._df = df
+
+        return self._df
+
+
+class Aggsv2Set(dict):
+    def __init__(self, raw):
+        ticker_ticks = {}
+        for tick in raw['results']:
+            if ticker_ticks.get(tick['T']):
+                ticker_ticks[tick['T']].append(tick)
+            else:
+                ticker_ticks[tick['T']] = [tick]
+        super().__init__({
+            ticker: Aggsv2({'results': ticks})
+            for ticker, ticks in ticker_ticks.items()
+        })
+
+
 class _TradeOrQuote(object):
     '''Mixin for Trade and Quote'''
 
@@ -207,3 +245,7 @@ class News(Entity):
 
 class NewsList(EntityList):
     _entity_class = News
+
+
+class Ticker(Entity):
+    pass
